@@ -1,5 +1,5 @@
 # only run this test on CI platforms
-if (.Platform$OS.type == 'unix' && !is.na(Sys.getenv('CI', NA))) {
+if (.Platform$OS.type == 'unix' && !is.na(Sys.getenv('CI', NA)) && rmarkdown::pandoc_available()) {
 
   # test if Word documents can be rendered with a specified intermediate dir
   # (https://github.com/rstudio/rmarkdown/issues/1431)
@@ -22,4 +22,16 @@ if (.Platform$OS.type == 'unix' && !is.na(Sys.getenv('CI', NA))) {
       }
     }
   )
+
+  # the default LaTeX template should work with multiple authors:
+  # https://github.com/rstudio/rmarkdown/issues/1716
+  rmarkdown::render('rmd/two-authors.Rmd')
+
+  # R code in YAML should be evaluated before YAML is passed to Pandoc:
+  # https://github.com/rstudio/rmarkdown/issues/1709
+  rmarkdown::render('rmd/yaml-r-code.Rmd')
+
+  # raw blocks in header-includes should work:
+  # https://github.com/rstudio/rmarkdown/issues/1729
+  rmarkdown::render('rmd/raw-header.Rmd')
 }
